@@ -10,7 +10,7 @@ import pytest
 import yaml
 
 from gordo import __version__
-from gordo.machine.dataset.datasets import TimeSeriesDataset
+from gordo_dataset.datasets import TimeSeriesDataset
 from gordo.machine import Machine
 from gordo.workflow.config_elements.normalized_config import NormalizedConfig
 from gordo.workflow.workflow_generator.workflow_generator import get_dict_from_yaml
